==> zio-aws-kafka_2.13-5.17.104.8-sources.jar: zio/aws/kafka/model/JmxExporterInfo.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__boolean
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class JmxExporterInfo(enabledInBroker: __boolean) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.JmxExporterInfo = {
    import JmxExporterInfo.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.JmxExporterInfo
      .builder()
      .enabledInBroker(__boolean.unwrap(enabledInBroker): java.lang.Boolean)
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.JmxExporterInfo.ReadOnly =
    zio.aws.kafka.model.JmxExporterInfo.wrap(buildAwsValue())
}
object JmxExporterInfo {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.JmxExporterInfo
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.JmxExporterInfo =
      zio.aws.kafka.model.JmxExporterInfo(enabledInBroker)
    def enabledInBroker: __boolean
    def getEnabledInBroker: ZIO[Any, Nothing, __boolean] =
      ZIO.succeed(enabledInBroker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.JmxExporterInfo
  ) extends zio.aws.kafka.model.JmxExporterInfo.ReadOnly {
    override val enabledInBroker: __boolean =
      zio.aws.kafka.model.primitives.__boolean(impl.enabledInBroker())
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.JmxExporterInfo
  ): zio.aws.kafka.model.JmxExporterInfo.ReadOnly = new Wrapper(impl)
}

==> zio-aws-kafka_2.13-6.20.42.1-sources.jar: zio/aws/kafka/model/JmxExporterInfo.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__boolean
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class JmxExporterInfo(enabledInBroker: __boolean) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.JmxExporterInfo = {
    import JmxExporterInfo.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.JmxExporterInfo
      .builder()
      .enabledInBroker(enabledInBroker: java.lang.Boolean)
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.JmxExporterInfo.ReadOnly =
    zio.aws.kafka.model.JmxExporterInfo.wrap(buildAwsValue())
}
object JmxExporterInfo {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.JmxExporterInfo
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.JmxExporterInfo =
      zio.aws.kafka.model.JmxExporterInfo(enabledInBroker)
    def enabledInBroker: __boolean
    def getEnabledInBroker: ZIO[Any, Nothing, __boolean] =
      ZIO.succeed(enabledInBroker)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.JmxExporterInfo
  ) extends zio.aws.kafka.model.JmxExporterInfo.ReadOnly {
    override val enabledInBroker: __boolean = impl.enabledInBroker(): __boolean
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.JmxExporterInfo
  ): zio.aws.kafka.model.JmxExporterInfo.ReadOnly = new Wrapper(impl)
}
